Learn R Programming

cgdsr (version 1.2.5)

cgdsr-getMutationData: Get mutation data for cancer study

Description

Queries the CGDS API and returns mutation data for a given case set and list of genes.

Usage

"getMutationData"(x, caseList, geneticProfile, genes, ...)

Arguments

x
A CGDS object (required)
caseList
A case list ID
geneticProfile
A genetic profile ID with mutation data
genes
A vector of query genes
...
Not used.

Value

case IDs, and columns corresponding to:
  1. entrez_gene_id: Entrez gene ID
  2. gene_symbol: HUGO gene symbol
  3. sequencing_center: Sequencer Center responsible for identifying this mutation.
  4. mutation_status: somatic or germline mutation status. all mutations returned will be of type somatic.
  5. age_at_diagnosis: Age at diagnosis.
  6. mutation_type: mutation type, such as nonsense, missense, or frameshift_ins.
  7. validation_status: validation status. Usually valid, invalid, or unknown.
  8. amino_acid_change: amino acid change resulting from the mutation.
  9. functional_impact_score: predicted functional impact score, as predicted by Mutation Assessor.
  10. xvar_link: Link to the Mutation Assessor web site.
  11. xvar_link_pdb: Link to the Protein Data Bank (PDB) View within Mutation Assessor web site.
  12. xvar_link_msa: Link the Multiple Sequence Alignment (MSA) view within the Mutation Assessor web site.
  13. chr: chromosome where mutation occurs.
  14. start_position: start position of mutation.
  15. end_position: end position of mutation

References

cBio Cancer Genomics Portal: http://www.cbioportal.org/

See Also

cgdsr,CGDS

Examples

Run this code
# Create CGDS object
mycgds = CGDS("http://www.cbioportal.org/")

getCancerStudies(mycgds)

# Get available case lists (collection of samples) for a given cancer study 
# Get Extended Mutation Data for EGFR and PTEN in TCGA GBM
#
# getMutationData(mycgds,gbm_tcga_all,gbm_tcga_mutations,c('EGFR','PTEN'))

Run the code above in your browser using DataLab